require 'spec_helper'

describe 'Collections API -> /collections' do
  let(:token) { 'thVEvafigsp9nCMGiA5XlOSQ2lzNCBLl' }
  let(:wrapper) { Passety::Wrapper.new(token) }
  let(:collection_id) { 1 }
  let(:tid) { 'AABAM' }

  context 'Getting Collection List', vcr: { cassette_name: 'collections/all' } do
    subject(:result) { wrapper.collections.all }

    it 'has 200 (OK) status' do
      expect(result.status).to eq(200)
    end

    it 'is paginated' do
      expect(result.parsed).to include('meta')
    end

    it 'returns list of collections' do
      expect(result.parsed).to include('collections')
    end
  end

  context 'Getting Collection\'s profile', vcr: { cassette_name: 'collections/find' } do
    subject(:result) { wrapper.collections.find(collection_id) }

    it 'has 200 (OK) status' do
      expect(result.status).to eq(200)
    end

    it 'contains information of collection' do
      expect(result.parsed['id']).to eq(collection_id)
    end
  end

  context 'Creating Collection', vcr: { cassette_name: 'collections/create' } do
    let(:name) { 'My suppa-duppa collection' }
    subject(:result) { wrapper.collections.create(name: name) }

    it 'has 201 (Created) status' do
      expect(result.status).to eq(201)
    end

    it 'has information about created collection' do
      expect(result.parsed['name']).to eq(name)
    end
  end

  context 'Updating Collection', vcr: { cassette_name: 'collections/update' } do
    let(:new_name) { 'Brand new name' }
    subject(:result) { wrapper.collections.update(collection_id, name: new_name) }

    it 'has 200 (OK) status' do
      expect(result.status).to eq(200)
    end

    it 'has information about updated collection' do
      expect(result.parsed['name']).to eq(new_name)
    end
  end

  context 'Deleting Collection', vcr: { cassette_name: 'collections/delete' } do
    subject(:result) { wrapper.collections.destroy(collection_id) }

    it 'has 204 (No Content) status' do
      expect(result.status).to eq(204)
    end

    it 'has blank body' do
      expect(result.parsed).to be_nil
    end
  end

  context 'Getting Thing List out of the collection', vcr: { cassette_name: 'collections/things/all' } do
    subject(:result) { wrapper.collections.things.all(collection_id) }

    it 'has 200 (OK) status' do
      expect(result.status).to eq(200)
    end

    it 'is paginated' do
      expect(result.parsed).to include('meta')
    end

    it 'returns list of collections list' do
      expect(result.parsed).to include('things')
    end
  end

  context 'Adding Thing(s) to collection', vcr: { cassette_name: 'collections/things/create' } do
    subject(:result) { wrapper.collections.things.create(collection_id, ids: [ tid ]) }

    it 'has 200 (OK) status' do
      expect(result.status).to eq(200)
    end

    it 'has blank body' do
      expect(result.parsed).to eq(nil)
    end
  end

  context 'Removing Thing(s) to collection', vcr: { cassette_name: 'collections/things/remove' } do
    subject(:result) { wrapper.collections.things.remove(collection_id, ids: [ tid ]) }

    it 'has 204 (No Content) status' do
      expect(result.status).to eq(204)
    end

    it 'has blank body' do
      expect(result.parsed).to eq(nil)
    end
  end

  context 'Removing one specific Thing from the collection', vcr: { cassette_name: 'collections/things/delete' } do
    subject(:result) { wrapper.collections.things.destroy(collection_id, tid) }

    it 'has 204 (No Content) status' do
      expect(result.status).to eq(204)
    end

    it 'has blank body' do
      expect(result.parsed).to eq(nil)
    end
  end
end
