require 'spec_helper'

describe 'Property API -> /thigns/:tid/properties' do
  let(:token) { 'thVEvafigsp9nCMGiA5XlOSQ2lzNCBLl' }
  let(:wrapper) { Passety::Wrapper.new(token) }
  let(:tid) { 'AABAM' }

  context 'Getting properties list', vcr: { cassette_name: 'things/properties/all' } do
    subject(:result) { wrapper.things.properties.all(tid) }

    it 'has 200 (OK) status' do
      expect(result.status).to eq(200)
    end

    it 'is paginated' do
      expect(result.parsed).to include('meta')
    end

    it 'returns list of properties' do
      expect(result.parsed).to include('properties')
    end
  end

  context 'Getting Property with Key', vcr: { cassette_name: 'things/properties/find' } do
    let(:key) { 'description' }
    subject(:result) { wrapper.things.properties.find(tid, key) }

    it 'has 200 (OK) status' do
      expect(result.status).to eq(200)
    end

    it 'contains information about property' do
      expect(result.parsed['key']).to eq(key)
    end
  end

  context 'Creating Property', vcr: { cassette_name: 'things/properties/create' } do
    let(:key)   { 'description' }
    let(:value) { 'Thing Description' }
    subject(:result) { wrapper.things.properties.create(tid, key: key, value: value) }

    it 'has 201 (Created) status' do
      expect(result.status).to eq(201)
    end

    it 'contains information about created property' do
      expect(result.parsed['key']).to   eq(key)
      expect(result.parsed['value']).to eq(value)
    end
  end

  context 'Updating Property' do
    let(:key)   { 'description' }
    let(:value) { 'New value' }
    subject(:result) { wrapper.things.properties.update(tid, key, value: value) }

    it 'raises NotImplementedError' do
      expect { result }.to raise_error(NotImplementedError)
    end
  end

  context 'Delete Property', vcr: { cassette_name: 'things/properties/delete' } do
    let(:key) { 'description' }
    subject(:result) { wrapper.things.properties.destroy(tid, key: key) }

    it 'has 204 (No Content) status' do
      expect(result.status).to eq(204)
    end

    it 'has empty body' do
      expect(result.parsed).to eq(nil)
    end
  end
end

