require 'spec_helper'

describe'Things api -> /things' do
  let(:token) { 'thVEvafigsp9nCMGiA5XlOSQ2lzNCBLl' }
  let(:wrapper) { Passety::Wrapper.new(token) }
  let(:tid) { 'AABAM' }

  context 'List all things', vcr: { cassette_name: 'things/all' } do
    subject(:result) { wrapper.things.all }

    it 'has 200 (OK) status' do
      expect(result.status).to eq(200)
    end

    it 'is paginated' do
      expect(result.parsed).to include('meta')
    end

    it 'returns list of things' do
      expect(result.parsed).to include("things")
    end
  end

  context 'Getting Thing', vcr: { cassette_name: 'things/find' } do
    subject(:result) { wrapper.things.find(tid) }

    it 'has 200 (OK) status' do
      expect(result.status).to eq(200)
    end

    it 'has thing info' do
      expect(result.parsed['id']).to eq(tid)
    end
  end

  context 'Creating Thing', vcr: { cassette_name: 'things/create' } do
    let(:name) { 'Nikon D3100' }
    subject(:result) { wrapper.things.create(name: name) }

    it 'has 201 (Created) status' do
      expect(result.status).to eq(201)
    end

    it 'contains information about created thing' do
      expect(result.parsed['name']).to eq(name)
    end
  end

  context 'Updating Thing', vcr: { cassette_name: 'things/update' } do
    let(:new_name) { 'Canon 600D' }
    subject(:result) { wrapper.things.update(tid, name: new_name) }

    it 'has 200 (OK) status' do
      expect(result.status).to eq(200)
    end

    it 'contains information about updated thing' do
      expect(result.parsed['name']).to eq(new_name)
    end
  end

  context 'Deleting Thing', vcr: { cassette_name: 'things/delete' } do
    subject(:result) { wrapper.things.destroy(tid) }

    it 'has 204 (No Content) status' do
      expect(result.status).to eq(204)
    end

    it 'has empty body' do
      expect(result.parsed).to be_nil
    end
  end

  context 'Photo Thing' do
    context 'Getting photos list', vcr: { cassette_name: 'things/photos/all' } do
      subject(:result) { wrapper.things.photos.all(tid) }

      it 'has 200 (OK) status' do
        expect(result.status).to eq(200)
      end

      it 'is paginated' do
        expect(result.parsed).to include('meta')
      end

      it 'returns list of photos' do
        expect(result.parsed).to include('photos')
      end
    end

    context 'Adding Photo to Thing', vcr: { cassette_name: 'things/photos/create' } do
      let(:photo_id) { 1 }
      subject(:result) { wrapper.things.photos.create(tid, photo: photo_id) }

      it 'has 201 (Created) status' do
        expect(result.status).to eq(201)
      end
    end
  end
end
