require 'spec_helper'

describe Passety::Wrapper, vcr: true do
  let(:token) { 'thVEvafigsp9nCMGiA5XlOSQ2lzNCBLl' }
  let(:wrapper) { Passety::Wrapper.new(token) }
  let(:collection_id) { 1 }
  let(:tid) { 'AABAM' }

  it 'has API url set to Passety API endpoint' do
    connection = wrapper.send(:connection)
    expect(connection.url_prefix.to_s).to match(Passety::API_URL)
  end

  context 'Application Info', vcr: { cassette_name: 'common/info' } do
    subject(:result) { wrapper.info }

    it 'has 200 (OK) status' do
      expect(result.status).to eq(200)
    end

    it 'has information about application' do
      expect(result.parsed['resources']['core']).to include('limit')
    end
  end

  context 'Searching Items', vcr: { cassette_name: 'common/search' } do
    let(:name) { 'Nikon D3100' }
    subject(:result) { wrapper.search(:name) }

    it 'has 200 (OK) status' do
      expect(result.status).to eq(200)
    end

    it 'has information about searched thing' do
      expect(result.parsed).to include("items")
    end

    it 'is paginated' do
      expect(result.parsed).to include('meta')
    end
  end

  context 'Uploads' do
    context 'Create an upload', vcr: { cassette_name: 'common/uploads' } do
      let(:file) { double(tempfile: double(read: nil), content_type: 'image/jpg', original_filename: 'grumpy.jpg') }
      subject(:result) { wrapper.uploads.create(file: file, type: :photo) }

      it 'has 201 (Created) status' do
        expect(result.status).to eq(201)
      end
    end
  end
end
